@@ -3,7 +3,7 @@ package WebService::Blogger;
 use warnings;
 use strict;
 
-use Any::Moose;
+use Moose;
 use LWP::UserAgent;
 use HTTP::Request::Common;
 use XML::Simple;
@@ -27,15 +27,14 @@ has blogs => (
 
 # LWP:::UserAgent instance for all requests during the session.
 has ua => (
-    builder       => sub { LWP::UserAgent->new },
-    lazy_build    => 1,
-    is            => 'ro',
+    lazy_build => 1,
+    is         => 'ro',
 );
 
 # Speed Moose up.
 __PACKAGE__->meta->make_immutable;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 
 sub BUILDARGS {
@@ -104,6 +103,14 @@ sub creds_file_name {
 }
 
 
+sub _build_ua {
+    ## Populares 'ua' property.
+    my $self = shift;
+
+    return LWP::UserAgent->new;
+}
+
+
 sub _build_blogs {
     ## Populates 'blogs' property with list of instances of WebService::Blogger::Blog.
     my $self = shift;
